@@ -35,7 +35,7 @@ class DtUtilsTest(unittest.TestCase):
         self.assertEqual(dt_parse_iso("1970-01-01T00:00:00.000000+0000"), dt_utc_epoch())
         self.assertEqual(dt_parse_iso("1970-01-01T00:00:00.000000"), dt_utc_epoch())
 
-    @ddt.data(
+    data_dt_to_ts = [
         (dt_utc(1970, 1, 1), 0.0),
         (dt_utc(1969, 12, 31, 23, 59, 59), -1.0),
         (dt_utc(1969, 12, 31, 23, 59, 59, 1), -0.999999),
@@ -56,12 +56,14 @@ class DtUtilsTest(unittest.TestCase):
         (dt_utc(2100, 1, 1, 0, 0, 0, 1), 4102444800.000001),
         (dt_utc(2100, 1, 1, 0, 0, 0, 1000), 4102444800.001),
         (dt_utc(2100, 1, 1, 0, 0, 0, 999999), 4102444800.999999),
-    )
+    ]
+
+    @ddt.idata(data_dt_to_ts)
     @ddt.unpack
     def test_dt_to_ts(self, data, expect):
         self.assertEqual(expect, dt_to_ts(data))
 
-    @ddt.data(
+    data_dt_from_ts = [
         (0.0, dt_utc(1970, 1, 1)),
         (-1.0, dt_utc(1969, 12, 31, 23, 59, 59)),
         (-0.999999, dt_utc(1969, 12, 31, 23, 59, 59, 1)),
@@ -82,12 +84,14 @@ class DtUtilsTest(unittest.TestCase):
         (4102444800.000001, dt_utc(2100, 1, 1, 0, 0, 0, 1)),
         (4102444800.001, dt_utc(2100, 1, 1, 0, 0, 0, 1000)),
         (4102444800.999999, dt_utc(2100, 1, 1, 0, 0, 0, 999999)),
-    )
+    ]
+
+    @ddt.idata(data_dt_from_ts)
     @ddt.unpack
     def test_dt_from_ts(self, data, expect):
         self.assertEqual(expect, dt_from_ts(data))
 
-    @ddt.data(
+    data_dt_parse = [
         ("0001-01-01T00:00:00", "%Y-%m-%dT%H:%M:%S", dt_utc(1, 1, 1, 0, 0, 0)),
         ("9999-12-31T23:59:59", "%Y-%m-%dT%H:%M:%S", dt_utc(9999, 12, 31, 23, 59, 59)),
         ("1970-01-01", "%Y-%m-%d", dt_utc(1970, 1, 1)),
@@ -119,12 +123,14 @@ class DtUtilsTest(unittest.TestCase):
         ("1000/00-01-01/12:30:45", "%Y/%y-%m-%d/%H:%M:%S", dt_utc(2000, 1, 1, 12, 30, 45)),
         ("99/2999-12-31/12:30:45", "%y/%Y-%m-%d/%H:%M:%S", dt_utc(2999, 12, 31, 12, 30, 45)),
         ("00/1000-01-01/12:30:45", "%y/%Y-%m-%d/%H:%M:%S", dt_utc(1000, 1, 1, 12, 30, 45)),
-    )
+    ]
+
+    @ddt.idata(data_dt_parse)
     @ddt.unpack
     def test_dt_parse(self, dt_str, fmt_str, expect):
         self.assertEqual(expect, dt_parse(dt_str, fmt_str))
 
-    @ddt.data(
+    data_dt_format = [
         (dt_utc(1, 1, 1, 0, 0, 0), "%Y-%m-%dT%H:%M:%S", "0001-01-01T00:00:00"),
         (dt_utc(9999, 12, 31, 23, 59, 59), "%Y-%m-%dT%H:%M:%S", "9999-12-31T23:59:59"),
         (dt_utc(1970, 1, 1), "%Y-%m-%d", "1970-01-01"),
@@ -157,7 +163,9 @@ class DtUtilsTest(unittest.TestCase):
         (dt_utc(90, 1, 1, 0, 0, 0), "%Y/%y-%m-%d/%H:%M:%S", "0090/90-01-01/00:00:00"),
         (dt_utc(900, 1, 1, 0, 0, 0), "%Y/%y-%m-%d/%H:%M:%S", "0900/00-01-01/00:00:00"),
         (dt_utc(9000, 1, 1, 0, 0, 0), "%Y/%y-%m-%d/%H:%M:%S", "9000/00-01-01/00:00:00"),
-    )
+    ]
+
+    @ddt.idata(data_dt_format)
     @ddt.unpack
     def test_dt_format(self, dt, fmt_str, expect):
         self.assertEqual(expect, dt_format(dt, fmt_str))
