@@ -1,5 +1,5 @@
+import dataclasses
 import unittest
-from dataclasses import dataclass
 
 import ddt
 
@@ -7,7 +7,7 @@ from iker.common.utils.funcutils import lazy, memorized, singleton, unique_retur
 from iker.common.utils.randutils import randomizer
 
 
-@dataclass
+@dataclasses.dataclass
 class Counter(object):
     value: int = 0
 
